define(
//begin v1.x content
({
	insertTableTitle: "Insereix taula",
	modifyTableTitle: "Modifica taula",
	rows: "Files:",
	columns: "Columnes:",
	align: "Alinea:",
	cellPadding: "Emplenat de cel·la:",
	cellSpacing: "Espaiat de cel·la:",
	tableWidth: "Amplada de taula:",
	backgroundColor: "Color de fons:",
	borderColor: "Color del contorn",
	borderThickness: "Gruix del contorn",
	percent: "percentatge",
	pixels: "píxels",
	"default": "default",
	left: "esquerra",
	center: "centrat",
	right: "dreta",
	buttonSet: "Defineix", // translated elsewhere?
	buttonInsert: "Insereix",
	buttonCancel: "Cancel·la",

	selectTableLabel: "Selecciona taula",
	insertTableRowBeforeLabel: "Afegeix fila abans",
	insertTableRowAfterLabel: "Afegeix fila després",
	insertTableColumnBeforeLabel: "Afegeix columna abans",
	insertTableColumnAfterLabel: "Afegeix columna després",
	deleteTableRowLabel: "Suprimeix fila",
	deleteTableColumnLabel: "Suprimeix columna"
})
//end v1.x content
);
